HISTORY
-------

0.1.1
+++++

* First bugfix release since 1
* Fixed TTS (but still not as good as should, it goes by a nice voice now)
* Fixed translation problems when uppercase is used


0.1.0
+++++

* Made say threaded on vinisto response
* I18n for everything.
* Minor bugfixes

0.0.10
++++++

* Updated documentation

0.0.9
+++++

* Added Infrared support as a module

0.0.8
+++++

* Added support for response phrase.
* Added support to speaking a whole phrase with the keyword on it.

0.0.7
+++++

* Added parameter handling
